# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.yamlLoad

Module implementing checks for the use of yaml load functions.

### Global Attributes

None

### Classes

None

### Functions

checkYamlLoad | Function to check for the use of of yaml load functions.
getChecks | Public method to get a dictionary with checks handled by this module.

## checkYamlLoad

checkYamlLoad(reportError, context, config)

Function to check for the use of of yaml load functions.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up